package cz.moneta.test.regression.backoffice.ufooperations.regressionsbbo;

import cz.moneta.test.dsl.Harness;
import cz.moneta.test.dsl.ufo.operations.search.SearchBy;
import cz.moneta.test.dsl.util.DateUtils;
import cz.moneta.test.dsl.util.credentials.Keys;
import cz.moneta.test.dsl.util.task.ufo.operations.OperationsTasks;
import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.ParameterizedTestCase;
import cz.moneta.test.harness.annotations.TestScenarioWithOrder;
import cz.moneta.test.harness.support.auth.Credentials;
import cz.moneta.test.harness.support.auth.Key;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.params.provider.ValueSource;

import static cz.moneta.test.dsl.util.task.ufo.cb.CommercialTasks.JIRA_COMMENT_STORE_KEY;
import static cz.moneta.test.harness.annotations.Environment.PPE;

@TestScenarioWithOrder(name = "Print Templates Statements")
public class PrintTemplatesStatements {
    String department = "OPERATIONS_PAYMENTS_ZAKLAD";
    String category = "Výpovědi";
    String CIF;

    @Order(1)
    @ParameterizedTestCase(name = "Print template Statements another address", environments = {PPE})
    @ValueSource(strings = {
            "Výpověď běžného účtu - chybí č. účtu",
            "Výpověď spořícího účtu - chybné č. účtu",
            "Výpověď spořícího účtu - chybí č. účtu",
            "Výpověď běžného účtu - chybné č. účtu",
            "Žádost o doplnění č. účtu"
    })
    @JiraTestCase(id = "BOC-T8671")
    public void printTemplatesStatementsAnotherAddress(String printName, Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {
        this.CIF = "3000064750";
        OperationsTasks operationsTasksTasks = harness.tasks().ufo().operations();

        String printAlternateName = printName;
        if (printName.equals("Výpověď spořícího účtu - chybné č. účtu")) {
            printAlternateName = "Žádost o doplnění výpovědi spořícího účtu";
        } else if (printName.equals("Výpověď běžného účtu - chybné č. účtu")) {
            printAlternateName = "Žádost o doplnění výpovědi běžného účtu";
        }

        harness.store("PRINT_NAME", printName);
        harness.withUfo()
                .openLoginPage()
                .then(operationsTasksTasks.login().withCredentials(credentials))
                .clickRcRadio()
                .fillSearchInput(CIF)
                .searchBy(SearchBy.CIF)
                .onClientDetailsPage()
                .clickPrintLettersWithCif()
                .selectDepartment(department)
                .selectCategory(category)
                .selectTemplate(printName)
                .selectGenderIfVisible()
                .clickAnotherAddress()
                .fillNameInput("David Novák")
                .fillStreetInput("Dlouhá")
                .fillBuildingNumberInput("928")
                .fillStreetNumberInput("1")
                .fillCityInput("Praha")
                .fillPostalCodeInput("11000")
                .clickPrintWithAnotherAddress()
                .clickAddress()
                .clickPrint()
                .clickSaveToDmsIfNotChecked()
                .clickSend()
                .onClientDetailPage()
                .clickCorrespondence()
                .assertPrintName(printAlternateName)
                .assertDate(DateUtils.getFormattedTodayDate("d.M.yyyy"));
    }

    @Order(2)
    @ParameterizedTestCase(name = "Print template Statements DMS", environments = {PPE})
    @ValueSource(strings = {
            "Výpověď běžného účtu - chybí č. účtu",
            "Výpověď spořícího účtu - chybné č. účtu",
            "Výpověď spořícího účtu - chybí č. účtu",
            "Výpověď běžného účtu - chybné č. účtu",
            "Žádost o doplnění č. účtu"
    })
    @JiraTestCase(id = "BOC-T8633")
    public void printTemplatesStatementsDms(String printName, Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {
        this.CIF = "3000011599";
        OperationsTasks operationsTasksTasks = harness.tasks().ufo().operations();

        String printAlternateName = printName;
        if (printName.equals("Výpověď spořícího účtu - chybné č. účtu")) {
            printAlternateName = "Žádost o doplnění výpovědi spořícího účtu";
        } else if (printName.equals("Výpověď běžného účtu - chybné č. účtu")) {
            printAlternateName = "Žádost o doplnění výpovědi běžného účtu";
        }

        harness.store("PRINT_NAME", printName);
        harness.withUfo()
                .openLoginPage()
                .then(operationsTasksTasks.login().withCredentials(credentials))
                .then(operationsTasksTasks.printTemplateTasks().createPrintTemplateWithCif(CIF, department, category, printName))
                .clickSaveToDmsIfNotChecked()
                .clickSend()
                .onClientDetailPage()
                .clickCorrespondence()
                .assertPrintName(printAlternateName)
                .assertDate(DateUtils.getFormattedTodayDate("d.M.yyyy"));
    }

    @Order(3)
    @ParameterizedTestCase(name = "Print template Statements DOPIS", environments = {PPE})
    @ValueSource(strings = {
            "Výpověď spořícího účtu - chybí č. účtu",
            "Výpověď běžného účtu - chybné č. účtu",
            "Žádost o doplnění č. účtu"
    })
    @JiraTestCase(id = "BOC-T8670")
    public void printTemplatesStatementsLetter(String printName, Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {
        this.CIF = "3000060532";
        OperationsTasks operationsTasksTasks = harness.tasks().ufo().operations();

        String printAlternateName = printName;
        if (printName.equals("Výpověď spořícího účtu - chybné č. účtu")) {
            printAlternateName = "Žádost o doplnění výpovědi spořícího účtu";
        } else if (printName.equals("Výpověď běžného účtu - chybné č. účtu")) {
            printAlternateName = "Žádost o doplnění výpovědi běžného účtu";
        }

        harness.store("PRINT_NAME", printName);
        harness.withUfo()
                .openLoginPage()
                .then(operationsTasksTasks.login().withCredentials(credentials))
                .then(operationsTasksTasks.printTemplateTasks().createPrintTemplateWithCif(CIF, department, category, printName))
                .clickSaveToEts()
                .clickSend()
                .onClientDetailPage()
                .clickCorrespondence()
                .assertPrintName(printAlternateName)
                .assertDate(DateUtils.getFormattedTodayDate("d.M.yyyy"));
    }

    @Order(4)
    @ParameterizedTestCase(name = "Print template Statements Ib", environments = {PPE})
    @ValueSource(strings = {
            "Výpověď běžného účtu - chybí č. účtu",
            "Výpověď spořícího účtu - chybné č. účtu",
            "Výpověď spořícího účtu - chybí č. účtu",
            "Výpověď běžného účtu - chybné č. účtu",
            "Žádost o doplnění č. účtu"
    })
    @JiraTestCase(id = "BOC-T8683")
    public void printTemplatesStatementsIb(String printName, Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {
        this.CIF = "3000233810";
        OperationsTasks operationsTasksTasks = harness.tasks().ufo().operations();

        String printAlternateName = printName;
        if (printName.equals("Výpověď spořícího účtu - chybné č. účtu")) {
            printAlternateName = "Žádost o doplnění výpovědi spořícího účtu";
        } else if (printName.equals("Výpověď běžného účtu - chybné č. účtu")) {
            printAlternateName = "Žádost o doplnění výpovědi běžného účtu";
        }

        harness.store("PRINT_NAME", printName);
        harness.withUfo()
                .openLoginPage()
                .then(operationsTasksTasks.login().withCredentials(credentials))
                .then(operationsTasksTasks.printTemplateTasks().createPrintTemplateWithCif(CIF, department, category, printName))
                .clickSaveToIbIfNotChecked()
                .clickSend()
                .onClientDetailPage()
                .clickCorrespondence()
                .assertPrintName(printAlternateName)
                .assertDate(DateUtils.getFormattedTodayDate("d.M.yyyy"));
    }

    @Order(5)
    @ParameterizedTestCase(name = "Print template Statements Interactive", environments = {PPE})
    @ValueSource(strings = {
            "Výpověď všech smluv",
    })
    @JiraTestCase(id = "BOC-T8702")
    public void printTemplatesStatementsInteractive(String printName, Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {
        this.CIF = "9000174795";
        String title = "Ing. Dorota Omelková";
        OperationsTasks operationsTasksTasks = harness.tasks().ufo().operations();

        harness.store("PRINT_NAME", printName);
        harness.withUfo()
                .openLoginPage()
                .then(operationsTasksTasks.login().withCredentials(credentials))
                .fillSearchInput(CIF)
                .searchBy(SearchBy.CIF)
                .onClientDetailsPage()
                .clickPrintLettersWithCif()
                .then(operationsTasksTasks.printTemplateTasks().createPrintTemplateInteractive(department, category, printName, title));
    }

    @Order(6)
    @ParameterizedTestCase(name = "Print template Statements LOCAL", environments = {PPE})
    @ValueSource(strings = {
            "Výpověď běžného účtu - chybí č. účtu",
            "Výpověď spořícího účtu - chybné č. účtu",
            "Výpověď spořícího účtu - chybí č. účtu",
            "Výpověď běžného účtu - chybné č. účtu",
            "Žádost o doplnění č. účtu"
    })
    @JiraTestCase(id = "BOC-T8672")
    public void printTemplatesStatementsLocal(String printName, Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {
        this.CIF = "3000053846";
        OperationsTasks operationsTasksTasks = harness.tasks().ufo().operations();

        harness.store("PRINT_NAME", printName);
        harness.withUfo()
                .openLoginPage()
                .then(operationsTasksTasks.login().withCredentials(credentials))
                .then(operationsTasksTasks.printTemplateTasks().createPrintTemplateWithCif(CIF, department, category, printName))
                .clickSaveToLocal()
                .clickSendAndClosePrintWindow();
    }

    @AfterEach
    protected void teardown(Harness harness) {
        harness.store(JIRA_COMMENT_STORE_KEY,
                "\nUFO Session ID: " + harness.get("reports.tmfj.execution.commentufosessionid") +
                        "\nNázev dopisu: " + harness.get("PRINT_NAME") +
                        "\nCIF: " + CIF);
    }
}